@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.44 2003/07/08 15:17:08 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/calctool.c,v 1.59 2003/11/24 21:00:20 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -73,6 +73,9 @@ char *dtype_desc[] = {         /* Tooltips for each display mode value. */
     N_("Set display type to scientific format")
 };
 
+char *hyp_desc = N_("Set hyperbolic option for trigonometric functions");
+char *inv_desc = N_("Set inverse option for trigonometric functions");
+
 char *mode_str[]  = {          /* Strings for each mode value. */
     N_("BASIC"), N_("FINANCIAL"), N_("SCIENTIFIC")
 };
@@ -125,6 +128,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 
 /* str
    hstr
+   astr,
    mods
    value
    func_char
@@ -135,6 +139,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 1. */
 {
     N_("7"),
+    NULL,
     N_("Numeric 7"),
     { 0,     0,        0,           0,      0 },
     { GDK_7, GDK_KP_7, GDK_KP_Home, GDK_R7, 0 },
@@ -144,15 +149,17 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("8"),
+    NULL,
     N_("Numeric 8"),
     { 0,     0,        0,         0,      0 },
-    { GDK_8, GDK_KP_8, GDK_KP_Up, GDK_Up, 0 },
+    { GDK_8, GDK_KP_8, GDK_KP_Up, 0 },
     '8',
     M_NONE,
     do_number
 },
 {
     N_("9"),
+    NULL,
     N_("Numeric 9"),
     { 0,     0,        0,              0,      0 },
     { GDK_9, GDK_KP_9, GDK_KP_Page_Up, GDK_R9, 0 },
@@ -163,6 +170,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {    
     N_("/"),
     N_("Divide"),
+    NULL,
     { 0,         0,             0,      0 },
     { GDK_slash, GDK_KP_Divide, GDK_R5, 0 },
     '/',
@@ -172,6 +180,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -181,6 +190,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Bsp"),
     N_("Remove rightmost character from displayed value"),
+    N_("Backspace"),
     { 0, 0 },
     { GDK_BackSpace, 0 },
     '\010',
@@ -190,8 +200,9 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("CE"),
     N_("Clear displayed value"),
-    { GDK_CONTROL_MASK, 0 },
-    { GDK_BackSpace, 0 },
+    N_("Clear entry"),
+    { GDK_CONTROL_MASK, 0,          0 },
+    { GDK_BackSpace,    GDK_Escape, 0 },
     '\013',
     M_NONE,
     do_clear_entry
@@ -199,6 +210,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Clr"),
     N_("Clear displayed value and any partial calculation"),
+    N_("Clear"),
     { 0, 0 },
     { GDK_Delete, 0 },
     '\177',
@@ -209,15 +221,17 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 2. */
 {
     N_("4"),
+    NULL,
     N_("Numeric 4"),
     { 0,     0,        0,           0,        0 },
-    { GDK_4, GDK_KP_4, GDK_KP_Left, GDK_Left, 0 },
+    { GDK_4, GDK_KP_4, GDK_KP_Left, 0 },
     '4',
     M_NONE,
     do_number
 },
 {
     N_("5"),
+    NULL,
     N_("Numeric 5"),
     { 0,     0,        0,            0,       0 },
     { GDK_5, GDK_KP_5, GDK_KP_Begin, GDK_R11, 0 },
@@ -227,9 +241,10 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("6"),
+    NULL,
     N_("Numeric 6"),
     { 0,     0,        0,            0,         0 },
-    { GDK_6, GDK_KP_6, GDK_KP_Right, GDK_Right, 0 },
+    { GDK_6, GDK_KP_6, GDK_KP_Right, 0 },
     '6',
     M_NONE,
     do_number
@@ -237,6 +252,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("*"),
     N_("Multiply"),
+    NULL,
     { GDK_SHIFT_MASK, 0,               0,     0,      0 },
     { GDK_asterisk,   GDK_KP_Multiply, GDK_x, GDK_R6, 0 },
     '*',
@@ -246,6 +262,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -255,15 +272,17 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("+/-"),
     N_("Change sign"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_C, 0 },
-    'C',
+    NULL,
+    { 0,     0 },
+    { GDK_c, 0 },
+    'c',
     M_NONE,
     do_immed
 },
 {
     N_("Int"),
     N_("Integer portion of displayed value"),
+    N_("Integer portion"),
     { 0, 0 },
     { GDK_i, 0 },
     'i',
@@ -273,6 +292,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Sto"),
     N_("Store displayed value in memory register"),
+    N_("Store to register"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_S, 0 },
     'S',
@@ -283,6 +303,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 3. */
 {
     N_("1"),
+    NULL,
     N_("Numeric 1"),
     { 0,     0,        0,          0,       0 },
     { GDK_1, GDK_KP_1, GDK_KP_End, GDK_R13, 0 },
@@ -292,15 +313,17 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 },
 {
     N_("2"),
+    NULL,
     N_("Numeric 2"),
     { 0,     0,        0,           0,        0 }, 
-    { GDK_2, GDK_KP_2, GDK_KP_Down, GDK_Down, 0 },
+    { GDK_2, GDK_KP_2, GDK_KP_Down, 0 },
     '2',
     M_NONE,
     do_number
 },    
 {     
     N_("3"),
+    NULL,
     N_("Numeric 3"),
     { 0,     0,        0,                0,       0 },
     { GDK_3, GDK_KP_3, GDK_KP_Page_Down, GDK_R15, 0 },
@@ -311,6 +334,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("-"),
     N_("Subtract"),
+    NULL,
     { 0,         0,               0,      0 },
     { GDK_minus, GDK_KP_Subtract, GDK_R4, 0 },
     '-',
@@ -320,6 +344,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("%"),
     N_("Percentage"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_percent, 0 },
     '%',
@@ -329,6 +354,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Sqrt"),
     N_("Square root"),
+    NULL,
     { 0, 0 },   
     { GDK_s, 0 },
     's',
@@ -338,6 +364,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Frac"),
     N_("Fractional portion of displayed value"),
+    N_("Fractional portion"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_colon, 0 },
     ':',
@@ -347,6 +374,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Rcl"),
     N_("Retrieve memory register to display"),
+    N_("Retrieve from register"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_R, 0 },
     'R',
@@ -357,6 +385,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 /* Row 4. */
 {
     N_("0"),
+    NULL,
     N_("Numeric 0"),
     { 0,     0,        0,             0 },
     { GDK_0, GDK_KP_0, GDK_KP_Insert, 0 },
@@ -367,6 +396,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {    
     N_("."),
     N_("Numeric point"),
+    NULL,
     { 0,          0,              0,             0 },
     { GDK_period, GDK_KP_Decimal, GDK_KP_Delete, GDK_KP_Separator, 0 },
     '.',
@@ -376,8 +406,9 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("="),
     N_("Calculate result"),
-    { 0,         0,            0,          0 },
-    { GDK_equal, GDK_KP_Enter, GDK_Return, 0 },
+    NULL,
+    { 0,         0,            0,          GDK_SHIFT_MASK, 0 },
+    { GDK_equal, GDK_KP_Enter, GDK_Return, GDK_Return,     0 },
     '=',
     M_NONE,
     do_calc
@@ -385,15 +416,17 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("+"),
     N_("Add"),
-    { GDK_SHIFT_MASK, 0,          0 },
-    { GDK_plus,       GDK_KP_Add, 0 },
+    NULL,
+    { GDK_SHIFT_MASK, 0,        0,          0 },
+    { GDK_plus,       GDK_plus, GDK_KP_Add, 0 },
     '+',
     M_NONE,
     do_calc
 },
 {
-    N_("1/x"),
+    N_("1/<i>x</i>"),
     N_("Reciprocal"),
+    NULL,
     { 0, 0 },
     { GDK_r, 0 },
     'r',
@@ -401,8 +434,9 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
     do_immed
 },
 {
-    N_("x<sup>2</sup>"),
+    N_("x<sup><i>2</i></sup>"),
     N_("Square"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_at, 0 },
     '@',
@@ -412,6 +446,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Abs"),
     N_("Absolute value"),
+    NULL,
     { 0, 0 },
     { GDK_u, 0 },
     'u',
@@ -421,6 +456,7 @@ struct button b_buttons[B_NOBUTTONS] = {   /* Basic mode button values. */
 {
     N_("Exch"),
     N_("Exchange displayed value with memory register"),
+    N_("Exchange with register"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_X, 0 },
     'X',
@@ -433,6 +469,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 
 /* str
    hstr
+   astr
    mods
    value
    func_char
@@ -445,6 +482,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Ctrm"),
     N_("Compounding term"),
+    NULL,
     { 0, 0 },
     { GDK_m, 0 },
     'm',
@@ -454,15 +492,17 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Ddb"),
     N_("Double-declining depreciation"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_D, 0 },
-    'D',
+    NULL,
+    { 0,     0 },
+    { GDK_d, 0 },
+    'd',
     M_NONE,
     do_business
 },
 {
     N_("Fv"),
     N_("Future value"),
+    NULL,
     { 0, 0 },
     { GDK_v, 0 },
     'v',
@@ -472,6 +512,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Pmt"),
     N_("Periodic payment"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_P, 0 },
     'P',
@@ -481,6 +522,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Pv"),
     N_("Present value"),
+    NULL,
     { 0, 0 },
     { GDK_p, 0 },
     'p',
@@ -490,6 +532,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Rate"),
     N_("Periodic interest rate"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_T, 0 },
     'T',
@@ -499,6 +542,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     N_("Sln"),
     N_("Straight-line depreciation"),
+    NULL,
     { 0, 0 },
     { GDK_l, 0 },
     'l',
@@ -508,6 +552,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     N_("Syd"),
     N_("Sum-of-the years'-digits depreciation"),
+    NULL,
     { 0, 0 },
     { GDK_Y, 0 },
     'Y',
@@ -519,6 +564,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     N_("Term"),
     N_("Payment period"),
+    NULL,
     { 0, 0 },
     { GDK_T, 0 },
     'T',
@@ -528,6 +574,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -537,6 +584,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -546,6 +594,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -555,6 +604,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -564,6 +614,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -573,6 +624,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 { 
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -582,6 +634,7 @@ struct button f_buttons[F_NOBUTTONS] = {   /* Financial mode button values. */
 {
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -594,6 +647,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 
 /* str
    hstr
+   astr
    mods
    value
    func_char
@@ -606,6 +660,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("<"),
     N_("Shift displayed value 1-15 places to the left"),
+    N_("Shift left"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_less, 0 },
     '<',
@@ -615,6 +670,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_(">"),
     N_("Shift displayed value 1-15 places to the right"),
+    N_("Shift right"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_greater, 0 },
     '>',
@@ -624,6 +680,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {             
     N_("&amp;16"),
     N_("16-bit unsigned integer value of display"),
+    N_("16 bit unsigned integer"),
     { 0, 0 },        
     { GDK_bracketright, 0 },
     ']',
@@ -633,6 +690,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {             
     N_("&amp;32"),
     N_("32-bit unsigned integer value of display"),
+    N_("32 bit unsigned integer"),
     { 0, 0 },
     { GDK_bracketleft, 0 },
     '[',
@@ -642,6 +700,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     "    ",
     "    ",
+    NULL,
     { 0, 0 },
     { 0, 0 },
     ' ',
@@ -651,6 +710,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("("),
     N_("Start group of calculations"),
+    N_("Left bracket"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_parenleft, 0 },
     '(',
@@ -660,6 +720,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_(")"),
     N_("End group of calculations"),
+    N_("Right bracket"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_parenright, 0 },
     ')',
@@ -669,9 +730,10 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Acc"),
     N_("Set accuracy from 0 to 9 numeric places"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_A, 0 },
-    'A',
+    N_("Accuracy"),
+    { 0,     0 },
+    { GDK_a, 0 },
+    'a',
     M_ACC,
     do_pending
 },
@@ -680,6 +742,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Con"),
     N_("Constants"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },   
     { GDK_numbersign, 0 },   
     '#',
@@ -689,24 +752,27 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Fun"),
     N_("User-defined functions"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_F, 0 },
-    'F',
+    NULL,
+    { 0,     0 },
+    { GDK_f, 0 },
+    'f',
     M_FUN,
     do_pending
 },
 {
     N_("Exp"),
     N_("Enter an exponential number"),
-    { GDK_SHIFT_MASK, 0 },
-    { GDK_E, 0 },
-    'E',
+    N_("Exponential"),
+    { 0,     0 },
+    { GDK_e, 0 },
+    'e',
     M_NONE,
     do_expno
 },
 {
-    N_("e<sup>x</sup>"),
+    N_("e<sup><i>x</i></sup>"),
     N_("e to the power of displayed value"),
+    N_("E to the x"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_braceleft, 0 },
     '{',
@@ -714,8 +780,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },
 {
-    N_("10<sup>x</sup>"),
+    N_("10<sup><i>x</i></sup>"),
     N_("10 to the power of displayed value"),
+    N_("Ten to the x"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_braceright, 0 },
     '}',
@@ -723,8 +790,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_immed
 },       
 {        
-    N_("y<sup>x</sup>"),
+    N_("y<sup><i>x</i></sup>"),
     N_("y to the power of displayed value"),
+    N_("Y to the x"),
     { 0, 0 },   
     { GDK_y, 0 },
     'y',
@@ -732,8 +800,9 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
     do_calc
 },       
 {        
-    N_("x!"),
+    N_("<i>x</i>!"),
     N_("Factorial of displayed value"),
+    N_("Factorial"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_exclam, 0 },
     '!',
@@ -743,6 +812,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Rand"),
     N_("Random number in the range 0.0 to 1.0"),
+    N_("Random number"),
     { GDK_SHIFT_MASK, 0 },
     { GDK_question, 0 },
     '?',
@@ -754,33 +824,37 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("D"),
     N_("Hexadecimal digit D"),
-    { 0, 0 },
-    { GDK_d, 0 },
-    'd',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_D,          0 },
+    'D',
     M_NONE,
     do_number
 },
 {
     N_("E"),
     N_("Hexadecimal digit E"),
-    { 0, 0 },
-    { GDK_e, 0 },
-    'e',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_E,          0 },
+    'E',
     M_NONE,
     do_number
 },
 {
     N_("F"),
     N_("Hexadecimal digit F"),
-    { 0, 0 },
-    { GDK_f, 0 },
-    'f',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_F,          0 },
+    'F',
     M_NONE,
     do_number
 },
 {
     N_("Cos"),
     N_("Cosine"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_J, 0 },
     'J',
@@ -790,6 +864,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Sin"),
     N_("Sine"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_K, 0 },
     'K',
@@ -799,6 +874,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {        
     N_("Tan"),
     N_("Tangent"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_L, 0 },
     'L',
@@ -808,6 +884,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {      
     N_("Ln"),
     N_("Natural log"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_N, 0 },
     'N',
@@ -817,6 +894,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 { 
     N_("Log"),
     N_("Base 10 log"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_G, 0 },
     'G',
@@ -828,33 +906,37 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("A"),
     N_("Hexadecimal digit A"),
-    { 0, 0 },
-    { GDK_a, 0 },
-    'a',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_A,          0 },
+    'A',
     M_NONE,
     do_number
 },
 {
     N_("B"),
     N_("Hexadecimal digit B"),
-    { 0, 0 },
-    { GDK_b, 0 },
-    'b',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_B,          0 },
+    'B',
     M_NONE,
     do_number
 },    
 {     
     N_("C"),
     N_("Hexadecimal digit C"),
-    { 0, 0 },
-    { GDK_c, 0 },
-    'c',
+    NULL,
+    { GDK_SHIFT_MASK, 0 },
+    { GDK_C,          0 },
+    'C',
     M_NONE,
     do_number
 },
 {
     N_("Or"),
     N_("Logical OR"),
+    "logical OR",
     { GDK_SHIFT_MASK, 0 },
     { GDK_bar, 0 },
     '|',
@@ -864,6 +946,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("And"),
     N_("Logical AND"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_ampersand, 0 },
     '&',
@@ -873,6 +956,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {        
     N_("Not"),
     N_("Logical NOT"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_asciitilde, 0 },
     '~',
@@ -882,6 +966,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Xor"),
     N_("Logical XOR"),
+    NULL,
     { GDK_SHIFT_MASK, 0 },
     { GDK_caret, 0 },
     '^',
@@ -891,6 +976,7 @@ struct button s_buttons[S_NOBUTTONS] = {   /* Scientific mode button values. */
 {
     N_("Xnor"),
     N_("Logical XNOR"),
+    NULL,
     { 0, 0 },
     { GDK_n, 0 },
     'n',
@@ -931,6 +1017,8 @@ do_calctool(int argc, char **argv)
         }
     }
 
+    v->radix_char = get_radix_char();   /* Locale specific radix character. */
+
     init_text();               /* Setup text strings depending upon language. */
     init_vars();               /* Setup default values for variables. */
     load_resources();          /* Get resources from various places. */
