@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.26 2003/07/25 21:33:32 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.31 2003/11/24 18:45:21 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -106,12 +106,12 @@ initialise()
  */
 
 static char *
-make_fixed(int *MPnumber,int base, int cmax)
+make_fixed(int *MPnumber, int base, int cmax)
 {
-    char *optr;
+    char half[4], *optr;
     int MP1base[MP_SIZE], MP1[MP_SIZE], MP2[MP_SIZE], MPval[MP_SIZE];
     int ndig;                   /* Total number of digits to generate. */
-    int ddig;                   /* Number of digits to left of . */
+    int ddig;                   /* Number of digits to left of decimal sep. */
     int dval, n;
  
     optr = v->fnum;
@@ -125,7 +125,8 @@ make_fixed(int *MPnumber,int base, int cmax)
     mpcim(&basevals[base], MP1base);
 
     mppwr(MP1base, &v->accuracy, MP1);
-    MPstr_to_num("0.5", DEC, MP2);
+    SPRINTF(half, "0%c5", v->radix_char);
+    MPstr_to_num(half, DEC, MP2);
     mpdiv(MP2, MP1, MP1);
     mpadd(MPval, MP1, MPval);
 
@@ -145,7 +146,7 @@ make_fixed(int *MPnumber,int base, int cmax)
 
     while (ndig-- > 0) {
         if (ddig-- == 0) {
-            *optr++ = '.';
+            *optr++ = v->radix_char;
         }
         mpmul(MPval, MP1base, MPval);
         mpcmi(MPval, &dval);
@@ -167,7 +168,7 @@ make_fixed(int *MPnumber,int base, int cmax)
         while (*optr == '0') {
             optr--;
         }
-        if (*optr != '.') {
+        if (*optr != v->radix_char) {
             optr++;
         }
         *optr = '\0';
@@ -201,12 +202,6 @@ make_number(int *MPnumber, int base, BOOLEAN mkFix, BOOLEAN ignoreError)
         (v->dtype == SCI) ||
         (v->dtype == FIX && val != 0.0 && (val > max_fix[base]))) {
         return(make_eng_sci(MPnumber, base));
-    } else if (v->dtype == FIX && val != 0.0 && mkFix) {
-        if (val <= min_fix[v->accuracy][base]) {
-            return(make_eng_sci(MPnumber, base));
-        } else {
-            return(make_fixed(MPnumber, base, MAX_DIGITS));
-        }
     } else {
         return(make_fixed(MPnumber, base, MAX_DIGITS));
     }
@@ -218,7 +213,7 @@ make_number(int *MPnumber, int base, BOOLEAN mkFix, BOOLEAN ignoreError)
 static char *
 make_eng_sci(int *MPnumber, int base)
 {
-    char fixed[MAX_DIGITS+1], *optr;
+    char half[4], fixed[MAX_DIGITS+1], *optr;
     int MP1[MP_SIZE], MPatmp[MP_SIZE], MPval[MP_SIZE];
     int MP1base[MP_SIZE], MP3base[MP_SIZE], MP10base[MP_SIZE];
     int i, dval, len, n;
@@ -292,7 +287,8 @@ make_eng_sci(int *MPnumber, int base)
         *optr++ = '+';
     }
  
-    MPstr_to_num("0.5", DEC, MP1);
+    SPRINTF(half, "0%c5", v->radix_char);
+    MPstr_to_num(half, DEC, MP1);
     mpaddi(MP1, &exp, MPval);
     n = 1;
     mpcim(&n, MP1);
@@ -340,7 +336,7 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
         optr++;
     }
 
-    if (*optr == '.') {
+    if (*optr == v->radix_char) {
         for (i = 1; (inum = char_val(*++optr)) >= 0; i++) {
             mppwr(MPbase, &i, MP1);
             mpcim(&inum, MP2);
