@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.102 2003/09/24 18:17:06 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/gtk.c,v 1.104 2003/11/07 18:47:30 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -792,6 +792,7 @@ create_kframe()
         v->tool_label = malloc(strlen(_("Calculator")) + strlen(hn) + 3);
 
         SPRINTF(v->tool_label, "%s %s", _("Calculator"), hn);
+        g_free(hn);
     } else {
         read_str(&v->tool_label, v->titleline);
     }
@@ -1185,6 +1186,7 @@ get_display()              /* The Copy function key has been pressed. */
         free(v->shelf);
     }
     v->shelf = g_locale_from_utf8(string, strlen(string), NULL, NULL, NULL);
+    g_free(string);
 
     gtk_clipboard_set_text(gtk_clipboard_get(X->clipboard_atom), v->shelf, -1);
 }
@@ -1325,8 +1327,6 @@ check_vals(int n, int keyval, int state,
             if (buttons[i].value[j] == keyval) {
                 if (buttons[i].mods[j] == state) {
                     button_proc(GTK_BUTTON(gtk_buttons[i]), NULL);
-                    g_signal_emit_by_name(GTK_WIDGET(gtk_buttons[i]), 
-                                          "activate");
                     return(TRUE);
                 }
             }
@@ -1344,14 +1344,6 @@ kframe_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
     GtkWidget *focus;
     int retval = FALSE;
 
-    if (event->keyval == GDK_space) {
-        focus = gtk_window_get_focus(GTK_WINDOW(X->kframe));
-        if (GTK_IS_BUTTON(focus) == TRUE) {
-            g_signal_emit_by_name(focus, "pressed");
-        }
-        return(FALSE);
-    }
-
     switch (v->modetype) {
         case BASIC:
             retval = check_vals(B_NOBUTTONS, event->keyval, event->state,
@@ -1487,7 +1479,7 @@ make_but_frame(GtkWidget *vbox, GtkWidget **Gtk_buttons,
                 Gtk_buttons[n] = make_menu_button(label, j*cols + i);
             }
             set_accessible_name(Gtk_buttons[n], buttons[n]);
-            g_signal_connect(G_OBJECT(Gtk_buttons[n]), "pressed",
+            g_signal_connect(G_OBJECT(Gtk_buttons[n]), "clicked",
                             G_CALLBACK(button_proc), (gpointer) (j*cols + i));
             SPRINTF(name, "%s_button%1d", tag, n);
             gtk_widget_set_name(Gtk_buttons[n], name);
